@@ -10,7 +10,7 @@ use strict;
 
 BEGIN {
 	$Module::Package::Dist::RDF::AUTHORITY = 'cpan:TOBYINK';
-	$Module::Package::Dist::RDF::VERSION   = '0.008';
+	$Module::Package::Dist::RDF::VERSION   = '0.009';
 	@Module::Package::Dist::RDF::ISA       = 'Module::Package::Dist';
 }
 
@@ -27,9 +27,20 @@ sub _main
 	use strict;
 	BEGIN {
 		$Module::Package::Dist::RDF::standard::AUTHORITY = 'cpan:TOBYINK';
-		$Module::Package::Dist::RDF::standard::VERSION   = '0.008';
+		$Module::Package::Dist::RDF::standard::VERSION   = '0.009';
 		@Module::Package::Dist::RDF::standard::ISA       = 'Module::Package::Dist::RDF';
 	}
 }
 
+{
+	package Module::Package::Dist::RDF::tobyink;
+	use 5.005;
+	use strict;
+	BEGIN {
+		$Module::Package::Dist::RDF::tobyink::AUTHORITY = 'cpan:TOBYINK';
+		$Module::Package::Dist::RDF::tobyink::VERSION   = '0.009';
+		@Module::Package::Dist::RDF::tobyink::ISA       = 'Module::Package::Dist::RDF';
+	}
+}
+
 1;
